@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -26,6 +26,10 @@ from .primitives import Int, Bytes
 class GzipPacked(Object):
     ID = 0x3072cfa1
 
+    __slots__ = ["packed_data"]
+
+    QUALNAME = "GzipPacked"
+
     def __init__(self, packed_data: Object):
         self.packed_data = packed_data
 
