@@ -24,10 +24,12 @@ from ...ext import BaseClient
 
 
 class KickChatMember(BaseClient):
-    def kick_chat_member(self,
-                         chat_id: Union[int, str],
-                         user_id: Union[int, str],
-                         until_date: int = 0) -> "pyrogram.Message":
+    def kick_chat_member(
+        self,
+        chat_id: Union[int, str],
+        user_id: Union[int, str],
+        until_date: int = 0
+    ) -> Union["pyrogram.Message", bool]:
         """Use this method to kick a user from a group, a supergroup or a channel.
         In the case of supergroups and channels, the user will not be able to return to the group on their own using
         invite links, etc., unless unbanned first. You must be an administrator in the chat for this to work and must
@@ -52,10 +54,10 @@ class KickChatMember(BaseClient):
                 considered to be banned forever. Defaults to 0 (ban forever).
 
         Returns:
-            True on success.
+            On success, either True or a service :obj:`Message <pyrogram.Message>` will be returned (when applicable).
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            :class:`RPCError <pyrogram.RPCError>` in case of a Telegram RPC error.
         """
         chat_peer = self.resolve_peer(chat_id)
         user_peer = self.resolve_peer(user_id)
@@ -65,7 +67,7 @@ class KickChatMember(BaseClient):
                 functions.channels.EditBanned(
                     channel=chat_peer,
                     user_id=user_peer,
-                    banned_rights=types.ChannelBannedRights(
+                    banned_rights=types.ChatBannedRights(
                         until_date=until_date,
                         view_messages=True,
                         send_messages=True,
@@ -93,3 +95,5 @@ class KickChatMember(BaseClient):
                     {i.id: i for i in r.users},
                     {i.id: i for i in r.chats}
                 )
+        else:
+            return True
