@@ -25,19 +25,13 @@ from ...ext import BaseClient
 
 
 class OnDeletedMessages(BaseClient):
-    def on_deleted_messages(self=None,
-                            filters=None,
-                            group: int = 0) -> callable:
-        """Use this decorator to automatically register a function for handling
-        deleted messages. This does the same thing as :meth:`add_handler` using the
-        :class:`DeletedMessagesHandler`.
-
-        .. note::
-            This decorator will wrap your defined function in a tuple consisting of *(Handler, group)*.
-
-            To reference your own function after it has been decorated, you need to access
-            *my_function[0].callback*, that is, the *callback* field of Handler object which is the the
-            first element in the tuple.
+    def on_deleted_messages(
+        self=None,
+        filters=None,
+        group: int = 0
+    ) -> callable:
+        """Use this decorator to automatically register a function for handling deleted messages.
+        This does the same thing as :meth:`add_handler` using the :class:`DeletedMessagesHandler`.
 
         Args:
             filters (:obj:`Filters <pyrogram.Filters>`):
