@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -16,23 +16,38 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+from typing import Tuple
+
 import pyrogram
+from pyrogram.client.handlers.handler import Handler
 from ...ext import BaseClient
 
 
 class OnRawUpdate(BaseClient):
-    def on_raw_update(self, group: int = 0):
-        """Use this decorator to automatically register a function for handling
-        raw updates. This does the same thing as :meth:`add_handler` using the
-        :class:`RawUpdateHandler`.
+    def on_raw_update(
+        self=None,
+        group: int = 0
+    ) -> callable:
+        """Use this decorator to automatically register a function for handling raw updates.
+        This does the same thing as :meth:`add_handler` using the :class:`RawUpdateHandler`.
 
         Args:
             group (``int``, *optional*):
                 The group identifier, defaults to 0.
         """
 
-        def decorator(func):
-            self.add_handler(pyrogram.RawUpdateHandler(func), group)
-            return func
+        def decorator(func: callable) -> Tuple[Handler, int]:
+            if isinstance(func, tuple):
+                func = func[0].callback
+
+            handler = pyrogram.RawUpdateHandler(func)
+
+            if isinstance(self, int):
+                return handler, group if self is None else group
+
+            if self is not None:
+                self.add_handler(handler, group)
+
+            return handler, group
 
         return decorator
