@@ -17,35 +17,38 @@
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 import binascii
-import mimetypes
 import os
 import struct
 from typing import Union
 
 import pyrogram
 from pyrogram.api import functions, types
-from pyrogram.api.errors import FileIdInvalid, FilePartMissing
+from pyrogram.errors import FileIdInvalid, FilePartMissing
 from pyrogram.client.ext import BaseClient, utils
 
 
 class SendAnimation(BaseClient):
-    def send_animation(self,
-                       chat_id: Union[int, str],
-                       animation: str,
-                       caption: str = "",
-                       parse_mode: str = "",
-                       duration: int = 0,
-                       width: int = 0,
-                       height: int = 0,
-                       thumb: str = None,
-                       disable_notification: bool = None,
-                       reply_to_message_id: int = None,
-                       reply_markup: Union["pyrogram.InlineKeyboardMarkup",
-                                           "pyrogram.ReplyKeyboardMarkup",
-                                           "pyrogram.ReplyKeyboardRemove",
-                                           "pyrogram.ForceReply"] = None,
-                       progress: callable = None,
-                       progress_args: tuple = ()) -> "pyrogram.Message":
+    def send_animation(
+        self,
+        chat_id: Union[int, str],
+        animation: str,
+        caption: str = "",
+        parse_mode: str = "",
+        duration: int = 0,
+        width: int = 0,
+        height: int = 0,
+        thumb: str = None,
+        disable_notification: bool = None,
+        reply_to_message_id: int = None,
+        reply_markup: Union[
+            "pyrogram.InlineKeyboardMarkup",
+            "pyrogram.ReplyKeyboardMarkup",
+            "pyrogram.ReplyKeyboardRemove",
+            "pyrogram.ForceReply"
+        ] = None,
+        progress: callable = None,
+        progress_args: tuple = ()
+    ) -> Union["pyrogram.Message", None]:
         """Use this method to send animation files (animation or H.264/MPEG-4 AVC video without sound).
 
         Args:
@@ -119,79 +122,83 @@ class SendAnimation(BaseClient):
 
         Returns:
             On success, the sent :obj:`Message <pyrogram.Message>` is returned.
+            In case the upload is deliberately stopped with :meth:`stop_transmission`, None is returned instead.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            :class:`RPCError <pyrogram.RPCError>` in case of a Telegram RPC error.
         """
         file = None
         style = self.html if parse_mode.lower() == "html" else self.markdown
 
-        if os.path.exists(animation):
-            thumb = None if thumb is None else self.save_file(thumb)
-            file = self.save_file(animation, progress=progress, progress_args=progress_args)
-            media = types.InputMediaUploadedDocument(
-                mime_type=mimetypes.types_map[".mp4"],
-                file=file,
-                thumb=thumb,
-                attributes=[
-                    types.DocumentAttributeVideo(
-                        supports_streaming=True,
-                        duration=duration,
-                        w=width,
-                        h=height
-                    ),
-                    types.DocumentAttributeFilename(os.path.basename(animation)),
-                    types.DocumentAttributeAnimated()
-                ]
-            )
-        elif animation.startswith("http"):
-            media = types.InputMediaDocumentExternal(
-                url=animation
-            )
-        else:
-            try:
-                decoded = utils.decode(animation)
-                fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                unpacked = struct.unpack(fmt, decoded)
-            except (AssertionError, binascii.Error, struct.error):
-                raise FileIdInvalid from None
-            else:
-                if unpacked[0] != 10:
-                    media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                    if media_type:
-                        raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                    else:
-                        raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                media = types.InputMediaDocument(
-                    id=types.InputDocument(
-                        id=unpacked[2],
-                        access_hash=unpacked[3],
-                        file_reference=b""
-                    )
+        try:
+            if os.path.exists(animation):
+                thumb = None if thumb is None else self.save_file(thumb)
+                file = self.save_file(animation, progress=progress, progress_args=progress_args)
+                media = types.InputMediaUploadedDocument(
+                    mime_type="video/mp4",
+                    file=file,
+                    thumb=thumb,
+                    attributes=[
+                        types.DocumentAttributeVideo(
+                            supports_streaming=True,
+                            duration=duration,
+                            w=width,
+                            h=height
+                        ),
+                        types.DocumentAttributeFilename(file_name=os.path.basename(animation)),
+                        types.DocumentAttributeAnimated()
+                    ]
                 )
-
-        while True:
-            try:
-                r = self.send(
-                    functions.messages.SendMedia(
-                        peer=self.resolve_peer(chat_id),
-                        media=media,
-                        silent=disable_notification or None,
-                        reply_to_msg_id=reply_to_message_id,
-                        random_id=self.rnd_id(),
-                        reply_markup=reply_markup.write() if reply_markup else None,
-                        **style.parse(caption)
-                    )
+            elif animation.startswith("http"):
+                media = types.InputMediaDocumentExternal(
+                    url=animation
                 )
-            except FilePartMissing as e:
-                self.save_file(animation, file_id=file.id, file_part=e.x)
             else:
-                for i in r.updates:
-                    if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
-                        return pyrogram.Message._parse(
-                            self, i.message,
-                            {i.id: i for i in r.users},
-                            {i.id: i for i in r.chats}
+                try:
+                    decoded = utils.decode(animation)
+                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
+                    unpacked = struct.unpack(fmt, decoded)
+                except (AssertionError, binascii.Error, struct.error):
+                    raise FileIdInvalid from None
+                else:
+                    if unpacked[0] != 10:
+                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
+
+                        if media_type:
+                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
+                        else:
+                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
+
+                    media = types.InputMediaDocument(
+                        id=types.InputDocument(
+                            id=unpacked[2],
+                            access_hash=unpacked[3],
+                            file_reference=b""
                         )
+                    )
+
+            while True:
+                try:
+                    r = self.send(
+                        functions.messages.SendMedia(
+                            peer=self.resolve_peer(chat_id),
+                            media=media,
+                            silent=disable_notification or None,
+                            reply_to_msg_id=reply_to_message_id,
+                            random_id=self.rnd_id(),
+                            reply_markup=reply_markup.write() if reply_markup else None,
+                            **style.parse(caption)
+                        )
+                    )
+                except FilePartMissing as e:
+                    self.save_file(animation, file_id=file.id, file_part=e.x)
+                else:
+                    for i in r.updates:
+                        if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
+                            return pyrogram.Message._parse(
+                                self, i.message,
+                                {i.id: i for i in r.users},
+                                {i.id: i for i in r.chats}
+                            )
+        except BaseClient.StopTransmission:
+            return None
