@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -23,25 +23,29 @@ from typing import Union
 
 import pyrogram
 from pyrogram.api import functions, types
-from pyrogram.api.errors import FileIdInvalid, FilePartMissing
+from pyrogram.errors import FileIdInvalid, FilePartMissing
 from pyrogram.client.ext import BaseClient, utils
 
 
 class SendPhoto(BaseClient):
-    def send_photo(self,
-                   chat_id: Union[int, str],
-                   photo: str,
-                   caption: str = "",
-                   parse_mode: str = "",
-                   ttl_seconds: int = None,
-                   disable_notification: bool = None,
-                   reply_to_message_id: int = None,
-                   reply_markup: Union["pyrogram.InlineKeyboardMarkup",
-                                       "pyrogram.ReplyKeyboardMarkup",
-                                       "pyrogram.ReplyKeyboardRemove",
-                                       "pyrogram.ForceReply"] = None,
-                   progress: callable = None,
-                   progress_args: tuple = ()) -> "pyrogram.Message":
+    def send_photo(
+        self,
+        chat_id: Union[int, str],
+        photo: str,
+        caption: str = "",
+        parse_mode: str = "",
+        ttl_seconds: int = None,
+        disable_notification: bool = None,
+        reply_to_message_id: int = None,
+        reply_markup: Union[
+            "pyrogram.InlineKeyboardMarkup",
+            "pyrogram.ReplyKeyboardMarkup",
+            "pyrogram.ReplyKeyboardRemove",
+            "pyrogram.ForceReply"
+        ] = None,
+        progress: callable = None,
+        progress_args: tuple = ()
+    ) -> Union["pyrogram.Message", None]:
         """Use this method to send photos.
 
         Args:
@@ -105,69 +109,73 @@ class SendPhoto(BaseClient):
 
         Returns:
             On success, the sent :obj:`Message <pyrogram.Message>` is returned.
+            In case the upload is deliberately stopped with :meth:`stop_transmission`, None is returned instead.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            :class:`RPCError <pyrogram.RPCError>` in case of a Telegram RPC error.
         """
         file = None
         style = self.html if parse_mode.lower() == "html" else self.markdown
 
-        if os.path.exists(photo):
-            file = self.save_file(photo, progress=progress, progress_args=progress_args)
-            media = types.InputMediaUploadedPhoto(
-                file=file,
-                ttl_seconds=ttl_seconds
-            )
-        elif photo.startswith("http"):
-            media = types.InputMediaPhotoExternal(
-                url=photo,
-                ttl_seconds=ttl_seconds
-            )
-        else:
-            try:
-                decoded = utils.decode(photo)
-                fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                unpacked = struct.unpack(fmt, decoded)
-            except (AssertionError, binascii.Error, struct.error):
-                raise FileIdInvalid from None
-            else:
-                if unpacked[0] != 2:
-                    media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                    if media_type:
-                        raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                    else:
-                        raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                media = types.InputMediaPhoto(
-                    id=types.InputPhoto(
-                        id=unpacked[2],
-                        access_hash=unpacked[3],
-                        file_reference=b""
-                    ),
+        try:
+            if os.path.exists(photo):
+                file = self.save_file(photo, progress=progress, progress_args=progress_args)
+                media = types.InputMediaUploadedPhoto(
+                    file=file,
                     ttl_seconds=ttl_seconds
                 )
-
-        while True:
-            try:
-                r = self.send(
-                    functions.messages.SendMedia(
-                        peer=self.resolve_peer(chat_id),
-                        media=media,
-                        silent=disable_notification or None,
-                        reply_to_msg_id=reply_to_message_id,
-                        random_id=self.rnd_id(),
-                        reply_markup=reply_markup.write() if reply_markup else None,
-                        **style.parse(caption)
-                    )
+            elif photo.startswith("http"):
+                media = types.InputMediaPhotoExternal(
+                    url=photo,
+                    ttl_seconds=ttl_seconds
                 )
-            except FilePartMissing as e:
-                self.save_file(photo, file_id=file.id, file_part=e.x)
             else:
-                for i in r.updates:
-                    if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
-                        return pyrogram.Message._parse(
-                            self, i.message,
-                            {i.id: i for i in r.users},
-                            {i.id: i for i in r.chats}
+                try:
+                    decoded = utils.decode(photo)
+                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
+                    unpacked = struct.unpack(fmt, decoded)
+                except (AssertionError, binascii.Error, struct.error):
+                    raise FileIdInvalid from None
+                else:
+                    if unpacked[0] != 2:
+                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
+
+                        if media_type:
+                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
+                        else:
+                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
+
+                    media = types.InputMediaPhoto(
+                        id=types.InputPhoto(
+                            id=unpacked[2],
+                            access_hash=unpacked[3],
+                            file_reference=b""
+                        ),
+                        ttl_seconds=ttl_seconds
+                    )
+
+            while True:
+                try:
+                    r = self.send(
+                        functions.messages.SendMedia(
+                            peer=self.resolve_peer(chat_id),
+                            media=media,
+                            silent=disable_notification or None,
+                            reply_to_msg_id=reply_to_message_id,
+                            random_id=self.rnd_id(),
+                            reply_markup=reply_markup.write() if reply_markup else None,
+                            **style.parse(caption)
                         )
+                    )
+                except FilePartMissing as e:
+                    self.save_file(photo, file_id=file.id, file_part=e.x)
+                else:
+                    for i in r.updates:
+                        if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
+                            return pyrogram.Message._parse(
+                                self, i.message,
+                                {i.id: i for i in r.users},
+                                {i.id: i for i in r.chats}
+                            )
+        except BaseClient.StopTransmission:
+            return None
