@@ -23,22 +23,26 @@ from typing import Union
 
 import pyrogram
 from pyrogram.api import functions, types
-from pyrogram.api.errors import FileIdInvalid, FilePartMissing
+from pyrogram.errors import FileIdInvalid, FilePartMissing
 from pyrogram.client.ext import BaseClient, utils
 
 
 class SendSticker(BaseClient):
-    def send_sticker(self,
-                     chat_id: Union[int, str],
-                     sticker: str,
-                     disable_notification: bool = None,
-                     reply_to_message_id: int = None,
-                     reply_markup: Union["pyrogram.InlineKeyboardMarkup",
-                                         "pyrogram.ReplyKeyboardMarkup",
-                                         "pyrogram.ReplyKeyboardRemove",
-                                         "pyrogram.ForceReply"] = None,
-                     progress: callable = None,
-                     progress_args: tuple = ()) -> Union["pyrogram.Message", None]:
+    def send_sticker(
+        self,
+        chat_id: Union[int, str],
+        sticker: str,
+        disable_notification: bool = None,
+        reply_to_message_id: int = None,
+        reply_markup: Union[
+            "pyrogram.InlineKeyboardMarkup",
+            "pyrogram.ReplyKeyboardMarkup",
+            "pyrogram.ReplyKeyboardRemove",
+            "pyrogram.ForceReply"
+        ] = None,
+        progress: callable = None,
+        progress_args: tuple = ()
+    ) -> Union["pyrogram.Message", None]:
         """Use this method to send .webp stickers.
 
         Args:
@@ -92,7 +96,7 @@ class SendSticker(BaseClient):
             In case the upload is deliberately stopped with :meth:`stop_transmission`, None is returned instead.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            :class:`RPCError <pyrogram.RPCError>` in case of a Telegram RPC error.
         """
         file = None
 
@@ -103,7 +107,7 @@ class SendSticker(BaseClient):
                     mime_type="image/webp",
                     file=file,
                     attributes=[
-                        types.DocumentAttributeFilename(os.path.basename(sticker))
+                        types.DocumentAttributeFilename(file_name=os.path.basename(sticker))
                     ]
                 )
             elif sticker.startswith("http"):
