@@ -21,6 +21,7 @@ from .get_me import GetMe
 from .get_user_profile_photos import GetUserProfilePhotos
 from .get_users import GetUsers
 from .set_user_profile_photo import SetUserProfilePhoto
+from .update_username import UpdateUsername
 
 
 class Users(
@@ -28,6 +29,7 @@ class Users(
     SetUserProfilePhoto,
     DeleteUserProfilePhotos,
     GetUsers,
-    GetMe
+    GetMe,
+    UpdateUsername
 ):
     pass
