@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -39,8 +39,12 @@ class InputMediaPhoto(InputMedia):
             Defaults to Markdown.
     """
 
-    def __init__(self,
-                 media: str,
-                 caption: str = "",
-                 parse_mode: str = ""):
+    __slots__ = []
+
+    def __init__(
+        self,
+        media: str,
+        caption: str = "",
+        parse_mode: str = ""
+    ):
         super().__init__(media, caption, parse_mode)
