@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -34,5 +34,32 @@ class DataCenter:
         121: "95.213.217.195"
     }
 
-    def __new__(cls, dc_id: int, test_mode: bool):
-        return (cls.TEST[dc_id], 80) if test_mode else (cls.PROD[dc_id], 443)
+    TEST_IPV6 = {
+        1: "2001:b28:f23d:f001::e",
+        2: "2001:67c:4e8:f002::e",
+        3: "2001:b28:f23d:f003::e",
+        121: "2a03:b0c0:3:d0::114:d001"
+    }
+
+    PROD_IPV6 = {
+        1: "2001:b28:f23d:f001::a",
+        2: "2001:67c:4e8:f002::a",
+        3: "2001:b28:f23d:f003::a",
+        4: "2001:67c:4e8:f004::a",
+        5: "2001:b28:f23f:f005::a",
+        121: "2a03:b0c0:3:d0::114:d001"
+    }
+
+    def __new__(cls, dc_id: int, test_mode: bool, ipv6: bool):
+        if ipv6:
+            return (
+                (cls.TEST_IPV6[dc_id], 80)
+                if test_mode
+                else (cls.PROD_IPV6[dc_id], 443)
+            )
+        else:
+            return (
+                (cls.TEST[dc_id], 80)
+                if test_mode
+                else (cls.PROD[dc_id], 443)
+            )
